/*

  This file is a part of GRALESHELL, a program to facilitate the simulation
  and inversion of gravitational lenses, based on the GRALE library.

  Copyright (C) 2008-2012 Jori Liesenborgs

  Contact: jori.liesenborgs@gmail.com
  
  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
  the Free Software Foundation; either version 2 of the License, or
  (at your option) any later version.
  
  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.
  
  You should have received a copy of the GNU General Public License
  along with this program; if not, write to the Free Software
  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
  
*/

#ifndef CMDUNITS_H

#define CMDUNITS_H

#include <shellp/shellcommand.h>
#include <shellp/shellcmdrealarg.h>

namespace shellp
{
	class ShellCmdStringArg;
	class ShellCmdRealArg;
}

class CmdUnitMassShow : public shellp::ShellCommand
{
public:
	CmdUnitMassShow(const std::string &cmdname);
	~CmdUnitMassShow();
	bool execute();
};

class CmdUnitAngularShow : public shellp::ShellCommand
{
public:
	CmdUnitAngularShow(const std::string &cmdname);
	~CmdUnitAngularShow();
	bool execute();
};

class CmdUnitDistanceShow : public shellp::ShellCommand
{
public:
	CmdUnitDistanceShow(const std::string &cmdname);
	~CmdUnitDistanceShow();
	bool execute();
};

class CmdUnitSet : public shellp::ShellCommand
{
protected:
	CmdUnitSet(const std::string &cmdname);
public:
	~CmdUnitSet();
protected:
	double GetMultiplier() const							{ return multarg->getValue(); }
private:
	shellp::ShellCmdRealArg *multarg;	
};

class CmdUnitMassSet : public CmdUnitSet
{
public:
	CmdUnitMassSet(const std::string &cmdname);
	~CmdUnitMassSet();
	bool execute();
private:
	shellp::ShellCmdStringArg *basearg;
};

class CmdUnitAngularSet : public CmdUnitSet
{
public:
	CmdUnitAngularSet(const std::string &cmdname);
	~CmdUnitAngularSet();
	bool execute();
private:
	shellp::ShellCmdStringArg *basearg;
};

class CmdUnitDistanceSet : public CmdUnitSet
{
public:
	CmdUnitDistanceSet(const std::string &cmdname);
	~CmdUnitDistanceSet();
	bool execute();
private:
	shellp::ShellCmdStringArg *basearg;
};

#endif // CMDUNITS_H

