/*

  This file is a part of GRALESHELL, a program to facilitate the simulation
  and inversion of gravitational lenses, based on the GRALE library.

  Copyright (C) 2008-2012 Jori Liesenborgs

  Contact: jori.liesenborgs@gmail.com
  
  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
  the Free Software Foundation; either version 2 of the License, or
  (at your option) any later version.
  
  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.
  
  You should have received a copy of the GNU General Public License
  along with this program; if not, write to the Free Software
  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
  
*/

#include "graleshellinstance.h"
#include <grale/openclkernel.h>

#include "debugnew.h"

void RegisterCommands();
void UnregisterCommands();

int main(int argc, char **argv)
{
#ifdef WIN32
	WSADATA dat;
	WSAStartup(MAKEWORD(2,2),&dat);
#endif // WIN32

	GraleShellInstance instance;

#ifdef GRALECONFIG_SUPPORT_OPENCL // TODO: add a command to do this
	grale::OpenCLKernel *pCLKernel = new grale::OpenCLKernel();

	if (!pCLKernel->init())
		delete pCLKernel;
	else
		instance.SetOpenCLKernel(pCLKernel);
#endif // GRALECONFIG_SUPPORT_OPENCL

	RegisterCommands();

	int returnStatus = instance.run("GraleShell", "graleshell> ", argc, argv);

	UnregisterCommands();

#ifdef WIN32
	WSACleanup();
#endif
	return returnStatus;
}



